@@ -23,7 +23,8 @@ def retry(max_num_retries: int) -> Callable[[Callable[P, Awaitable[R]]], Callabl
                     if remaining_retries < 0:
                         raise
                     else:
-                        logging.warn(f"Encountered error {sys.exc_info()[0]}: {sys.exc_info()[1]}. Retrying ({remaining_retries} remaining attempts)...")
+                        logging.warn(f"Encountered error {sys.exc_info()[0]}. Retrying ({remaining_retries} remaining attempts)...")
+                        logging.debug(f"Error was {sys.exc_info()[1]}")
                         # Let's sleep a bit just in case the server is in a temporarily bad state
                         await asyncio.sleep(1)
         return inner
